@@ -42,6 +42,15 @@
 #include "snprintf.h"
 #include "strdup.h"
 
+/* BeOS has AF_INET, but not PF_INET.  */
+#ifndef PF_INET
+# define PF_INET AF_INET
+#endif
+/* BeOS also lacks PF_UNSPEC.  */
+#ifndef PF_UNSPEC
+# define PF_UNSPEC 0
+#endif
+
 #if defined _WIN32 || defined __WIN32__
 # define WIN32_NATIVE
 #endif
@@ -140,6 +149,10 @@ getaddrinfo (const char *restrict nodename,
     return getaddrinfo_ptr (nodename, servname, hints, res);
 #endif
 
+  if (hints && (hints->ai_flags & ~(AI_CANONNAME|AI_PASSIVE)))
+    /* FIXME: Support more flags. */
+    return EAI_BADFLAGS;
+
   if (hints && !validate_family (hints->ai_family))
     return EAI_FAMILY;
 
@@ -148,14 +161,17 @@ getaddrinfo (const char *restrict nodename,
     /* FIXME: Support other socktype. */
     return EAI_SOCKTYPE; /* FIXME: Better return code? */
 
-  if ( ! nodename ) {
-          if ( ! (hints->ai_flags & AI_PASSIVE) )
-                  return EAI_NONAME;
-          
-          nodename = (hint->ai_family == AF_INET6) ? "::" : "0.0.0.0";
-  }
-  
-    /* FIXME: Support server bind mode. */
+  if (!nodename)
+    {
+      if (!(hints->ai_flags & AI_PASSIVE))
+	return EAI_NONAME;
+
+#ifdef HAVE_IPV6
+      nodename = (hint->ai_family == AF_INET6) ? "::" : "0.0.0.0";
+#else
+      nodename = "0.0.0.0";
+#endif
+    }
 
   if (servname)
     {
