@@ -27,4 +27,5 @@ void rule_regex_destroy(rule_regex_t *ptr);
 
 rule_regex_t *rule_regex_new(const char *regex, prelude_bool_t optionnal);
 
-int rule_regex_match(pcre_rule_container_t *root, const lml_log_source_t *ls, const lml_log_entry_t *log_entry, pcre_match_flags_t *match_flags);
+int rule_regex_match(pcre_plugin_t *plugin, pcre_rule_container_t *rc,
+                     const lml_log_source_t *ls, const lml_log_entry_t *log_entry, pcre_match_flags_t *match_flags);
