@@ -42,6 +42,11 @@
 #include "regex.h"
 #include "log-source.h"
 #include "udp-server.h"
+#include "lml-options.h"
+
+#ifndef MIN
+# define MIN(x, y) (((x) < (y)) ? (x) : (y))
+#endif
 
 
 /*
@@ -58,18 +63,40 @@
 struct udp_server {
         int sockfd;
         lml_log_source_t *ls;
-        regex_list_t *rlist;
+        char *addr;
+        unsigned int port;
 };
 
 
 
+extern lml_config_t config;
+
+
+
+static char *my_strnchr(char *input, char wanted, size_t size)
+{        
+        while ( *input && size-- ) {
+                if ( *input == 0 )
+                        break;
+                
+                if ( *input == wanted )
+                        return input;
+
+                input++;
+        }
+
+        return NULL;
+}
+
+
+
 void udp_server_process_event(udp_server_t *server)
 {
         ssize_t ret;
         socklen_t len;
         char src[512];
         struct sockaddr_in addr;
-        char buf[SYSLOG_MSG_MAX_SIZE], *ptr;
+        char buf[SYSLOG_MSG_MAX_SIZE], *ptr = NULL;
         
         len = sizeof(struct sockaddr);
 
@@ -79,39 +106,55 @@ void udp_server_process_event(udp_server_t *server)
                 return;
         }
 
+        if ( ret == 0 )
+                return;
+        
         buf[ret] = '\0';
         
         snprintf(src, sizeof(src), "%s:%d", inet_ntoa(addr.sin_addr), addr.sin_port);        
         lml_log_source_set_name(server->ls, src);
 
         /*
-         * we don't care about syslog priority / facility.
+         * We don't care about syslog priority / facility. From RFC 3164:
+         *
+         * - If the first character is not a less-than sign: no valid PRI.
+         * - If the 3rd, 4th, or 5th character is not a right angle bracket character: no valid PRI.
          */
-        ptr = strchr(buf, '>');
-        if ( ! ptr )
-                ptr = buf;
-        else {
-                ret--;
-                ptr++;
+        if ( buf[0] == '<' && ret > 2 ) {
+                ptr = my_strnchr(buf + 2, '>', MIN(ret - 2, 3));
+                if ( ptr ) {
+                        ptr++;
+                        ret -= (ptr - buf);
+                }
         }
         
-        lml_dispatch_log(server->rlist, server->ls, ptr, ret);
+        lml_dispatch_log(server->ls, ptr ? ptr : buf, ret);
 }
 
 
 
 void udp_server_close(udp_server_t *server)
-{
-        if ( server->ls )
-                lml_log_source_destroy(server->ls);
+{        
+        lml_log_source_destroy(server->ls);
 
-        regex_destroy(server->rlist);
-        
         close(server->sockfd);
+
+        free(server->addr);
         free(server);
 }
 
 
+const char *udp_server_get_addr(udp_server_t *server)
+{
+        return server->addr;
+}
+
+
+unsigned int udp_server_get_port(udp_server_t *server)
+{
+        return server->port;
+}
+
 
 int udp_server_get_event_fd(udp_server_t *server) 
 {
@@ -123,7 +166,7 @@ int udp_server_get_event_fd(udp_server_t *server)
 
 
 
-udp_server_t *udp_server_new(regex_list_t *rlist, const char *addr, unsigned int port)
+udp_server_t *udp_server_new(lml_log_source_t *ls,  const char *addr, unsigned int port)
 {
         int ret, sockfd;
         udp_server_t *server;
@@ -168,15 +211,10 @@ udp_server_t *udp_server_new(regex_list_t *rlist, const char *addr, unsigned int
                 return NULL;
         }
 
-        server->rlist = rlist;
+        server->addr = strdup(addr);
+        server->port = port;
         server->sockfd = sockfd;
-        
-        server->ls = lml_log_source_new();
-        if ( ! server->ls ) {
-                close(sockfd);
-                free(server);
-                return NULL;
-        }
+        server->ls = ls;
         
         return server;
 }
